@@ -1,7 +1,7 @@
 #define USE_PLUGIN
 
-#include "../../src/xchat.h"
-#include "../../src/plugin.h"
+#include "../../src/common/xchat.h"
+#include "../../src/common/plugin.h"
 
 extern	struct module *module_find (char *name);
 
