@@ -19,6 +19,9 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
 #include <string.h>
 #include <stdio.h>
 #include <sys/stat.h>
@@ -146,8 +149,14 @@ cfg_get_str (char *cfg, char *var, char *dest)
       {
          char *value, t;
          cfg += strlen (var);
-         while (*cfg == ' ' || *cfg == '=')
+         while (*cfg == ' ')
             cfg++;
+         if (*cfg == '=')
+            cfg++;
+         while (*cfg == ' ')
+            cfg++;
+         /*while (*cfg == ' ' || *cfg == '=')
+            cfg++;*/
          value = cfg;
          while (*cfg != 0 && *cfg != '\n')
             cfg++;
@@ -369,7 +378,7 @@ load_config (void)
    struct stat st;
    char *cfg, *username;
    int res, val, i, fh, am_root = 0;
-   char version[32];
+/*   char version[32];*/
 
    memset (&prefs, 0, sizeof (struct xchatprefs));
    /* Just for ppl upgrading --AGL */
@@ -411,7 +420,7 @@ load_config (void)
       }
       while (vars[i].type != 0);
 
-      cfg_get_str (cfg, "version", version);
+/*      cfg_get_str (cfg, "version", version);
       if (strcmp (version, VERSION) != 0)
       {
          fe_message (
@@ -421,7 +430,7 @@ load_config (void)
 "your serverlist.conf might be a good idea). Make sure you do it\n"
 "while X-Chat isn't running.\n"
                   , TRUE);
-      }
+      }*/
 
       free (cfg);
 
@@ -501,7 +510,7 @@ load_config (void)
    if (prefs.mainwindow_width < 116)
       prefs.mainwindow_width = 116;
    if (prefs.notify_timeout > 1000)
-      fprintf (stderr, "*** X-Chat: fix your notify timeout! It's too high.");
+      fprintf (stderr, "*** X-Chat: fix your notify timeout! It's too high\n");
    if (prefs.indent_pixels < 1)
       prefs.indent_pixels = 80;
    if (prefs.dialog_indent_pixels < 1)
