@@ -107,7 +107,7 @@ dcc_check_timeouts (void)
       dcc = (struct DCC *) list->data;
       next = list->next;
 
-      if (dcc->stat == STAT_ACTIVE)
+      if (dcc->dccstat == STAT_ACTIVE)
       {
          dcc_calc_cps (dcc);
 
@@ -122,7 +122,7 @@ dcc_check_timeouts (void)
          }
       }
 
-      switch (dcc->stat)
+      switch (dcc->dccstat)
       {
       case STAT_ACTIVE:
          if (dcc->type == TYPE_SEND || dcc->type == TYPE_RECV)
@@ -197,7 +197,7 @@ update_dcc_window (int type)
 }
 
 void
-dcc_close (struct DCC *dcc, int stat, int destroy)
+dcc_close (struct DCC *dcc, int dccstat, int destroy)
 {
    char type = dcc->type;
    if (dcc->sok != -1)
@@ -214,7 +214,7 @@ dcc_close (struct DCC *dcc, int stat, int destroy)
       close (dcc->fp);
       dcc->fp = -1;
    }
-   dcc->stat = stat;
+   dcc->dccstat = dccstat;
    if (dcc->dccchat)
    {
       free (dcc->dccchat);
@@ -274,7 +274,7 @@ dcc_write_chat (char *nick, char *text)
    dcc = find_dcc (nick, "", TYPE_CHATRECV);
    if (!dcc)
       dcc = find_dcc (nick, "", TYPE_CHATSEND);
-   if (dcc && dcc->stat == STAT_ACTIVE)
+   if (dcc && dcc->dccstat == STAT_ACTIVE)
    {
       len = strlen (text);
       dcc->size += len;
@@ -493,13 +493,13 @@ dcc_connect_finished (struct DCC *dcc, gint sok)
          EMIT_SIGNAL (XP_TE_DCCCONFAIL, dcc->serv->front_session,
                       dcctypes[(int) dcc->type], dcc->nick, errorstring (er),
                       NULL, 0);
-         dcc->stat = STAT_FAILED;
+         dcc->dccstat = STAT_FAILED;
          update_dcc_window (dcc->type);
          return;
       }
    }
    fcntl (sok, F_SETFL, O_NONBLOCK);
-   dcc->stat = STAT_ACTIVE;
+   dcc->dccstat = STAT_ACTIVE;
    switch (dcc->type)
    {
    case TYPE_RECV:
@@ -524,13 +524,13 @@ dcc_connect_finished (struct DCC *dcc, gint sok)
 void
 dcc_connect (struct session *sess, struct DCC *dcc)
 {
-   if (dcc->stat == STAT_CONNECTING)
+   if (dcc->dccstat == STAT_CONNECTING)
       return;
-   dcc->stat = STAT_CONNECTING;
+   dcc->dccstat = STAT_CONNECTING;
    dcc->sok = dcc_connect_sok (dcc);
    if (dcc->sok == -1)
    {
-      dcc->stat = STAT_FAILED;
+      dcc->dccstat = STAT_FAILED;
       update_dcc_window (dcc->type);
       return;
    }
@@ -644,7 +644,8 @@ dcc_accept (struct DCC *dcc, gint sokk)
 {
    char host[128];
    struct sockaddr_in CAddr;
-   int len, sok;
+   int sok;
+   size_t len;
 
    len = sizeof (CAddr);
    sok = accept (dcc->sok, (struct sockaddr *) &CAddr, &len);
@@ -659,7 +660,7 @@ dcc_accept (struct DCC *dcc, gint sokk)
    dcc->sok = sok;
    dcc->addr = ntohl (CAddr.sin_addr.s_addr);
    memcpy ((char *) &dcc->SAddr.sin_addr, (char *) &CAddr.sin_addr, sizeof (struct in_addr));
-   dcc->stat = STAT_ACTIVE;
+   dcc->dccstat = STAT_ACTIVE;
    dcc->lasttime = dcc->starttime = time (0);
    dcc->fastsend = prefs.fastdccsend;
    switch (dcc->type)
@@ -688,7 +689,7 @@ dcc_accept (struct DCC *dcc, gint sokk)
 static int
 dcc_listen_init (struct DCC *dcc)
 {
-   int len;
+   size_t len;
    unsigned long my_addr;
    unsigned long old_addr;
    struct sockaddr_in SAddr;
@@ -787,7 +788,7 @@ dcc_send (struct session *sess, char *tbuf, char *to, char *file)
          {
             dcc->offertime = time (0);
             dcc->serv = sess->server;
-            dcc->stat = STAT_QUEUED;
+            dcc->dccstat = STAT_QUEUED;
             dcc->size = st.st_size;
             dcc->type = TYPE_SEND;
             dcc->fp = open (dcc->file, OFLAGS | O_RDONLY);
@@ -836,7 +837,7 @@ find_dcc_from_port (int port, int type)
    {
       dcc = (struct DCC *) list->data;
       if (dcc->port == port &&
-          dcc->stat == STAT_QUEUED &&
+          dcc->dccstat == STAT_QUEUED &&
           dcc->type == type)
          return dcc;
       list = list->next;
@@ -897,7 +898,7 @@ dcc_get (struct DCC *dcc)
 {
    if (dcc)
    {
-      switch (dcc->stat)
+      switch (dcc->dccstat)
       {
       case STAT_QUEUED:
          dcc->resumable = 0;
@@ -923,7 +924,7 @@ dcc_get_nick (struct session *sess, char *nick)
       dcc = (struct DCC *) list->data;
       if (!strcasecmp (nick, dcc->nick))
       {
-         if (dcc->stat == STAT_QUEUED && dcc->type == TYPE_RECV)
+         if (dcc->dccstat == STAT_QUEUED && dcc->type == TYPE_RECV)
          {
             dcc->resumable = 0;
             dcc->pos = 0;
@@ -961,7 +962,7 @@ dcc_chat (struct session *sess, char *nick)
    dcc = find_dcc (nick, "", TYPE_CHATSEND);
    if (dcc)
    {
-      switch (dcc->stat)
+      switch (dcc->dccstat)
       {
       case STAT_ACTIVE:
       case STAT_QUEUED:
@@ -976,7 +977,7 @@ dcc_chat (struct session *sess, char *nick)
    dcc = find_dcc (nick, "", TYPE_CHATRECV);
    if (dcc)
    {
-      switch (dcc->stat)
+      switch (dcc->dccstat)
       {
       case STAT_QUEUED:
          dcc_connect (0, dcc);
@@ -994,7 +995,7 @@ dcc_chat (struct session *sess, char *nick)
       return;
    dcc->offertime = time (0);
    dcc->serv = sess->server;
-   dcc->stat = STAT_QUEUED;
+   dcc->dccstat = STAT_QUEUED;
    dcc->type = TYPE_CHATSEND;
    time (&dcc->starttime);
    dcc->nick = strdup (nick);
@@ -1026,7 +1027,7 @@ dcc_resume (struct DCC *dcc)
 
    if (dcc)
    {
-      if (dcc->stat == STAT_QUEUED && dcc->resumable)
+      if (dcc->dccstat == STAT_QUEUED && dcc->resumable)
       {
          snprintf (tbuf, sizeof tbuf, "PRIVMSG %s :\001DCC RESUME %s %d %lu\001\r\n",
                    dcc->nick, dcc->file, dcc->port, dcc->resumable);
@@ -1067,7 +1068,7 @@ handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[], char *
       {
          dcc->serv = sess->server;
          dcc->type = TYPE_CHATRECV;
-         dcc->stat = STAT_QUEUED;
+         dcc->dccstat = STAT_QUEUED;
          dcc->addr = addr;
          dcc->port = port;
          dcc->nick = strdup (nick);
@@ -1109,7 +1110,7 @@ handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[], char *
    {
       port = atol (word[7]);
       dcc = find_dcc_from_port (port, TYPE_RECV);
-      if (dcc && dcc->stat == STAT_QUEUED)
+      if (dcc && dcc->dccstat == STAT_QUEUED)
       {
          dcc_connect (0, dcc);
          return;
@@ -1156,7 +1157,7 @@ handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[], char *
             dcc->resumable = 0;
          dcc->serv = sess->server;
          dcc->type = TYPE_RECV;
-         dcc->stat = STAT_QUEUED;
+         dcc->dccstat = STAT_QUEUED;
          dcc->addr = addr;
          dcc->SAddr.sin_addr.s_addr = addr;
          dcc->port = port;
@@ -1204,7 +1205,7 @@ dcc_show_list (struct session *sess, char *outbuf)
       i++;
       snprintf (outbuf, 255, " %-5.5s %-10.10s %-7.7s %-7ld %-7ld %s\n",
                 dcctypes[(int) dcc->type], dcc->nick,
-                dccstat[(int) dcc->stat].name, dcc->size, dcc->pos, file_part (dcc->file));
+                dccstat[(int) dcc->dccstat].name, dcc->size, dcc->pos, file_part (dcc->file));
       PrintText (sess, outbuf);
       list = list->next;
    }
