@@ -243,6 +243,19 @@ tcp_send (struct server *serv, char *buf)
    return tcp_send_len (serv, buf, strlen (buf));
 }
 
+static int
+is_server (server *serv)
+{
+   GSList *list = serv_list;
+   while (list)
+   {
+      if (list->data == serv)
+         return 1;
+      list = list->next;
+   }
+   return 0;
+}
+
 int
 is_session (session *sess)
 {
@@ -344,8 +357,13 @@ find_session_from_waitchannel (char *chan, struct server *serv)
 static int
 timeout_auto_reconnect (struct server *serv)
 {
-   if (!serv->connected && !serv->connecting)
-      connect_server (serv->front_session, serv->hostname, serv->port, FALSE);
+   if (is_server (serv))   /* make sure it hasnt been closed during the delay */
+   {
+      if (!serv->connected && !serv->connecting && serv->front_session)
+      {
+         connect_server (serv->front_session, serv->hostname, serv->port, FALSE);
+      }
+   }
    return 0;         /* returning 0 should remove the timeout handler */
 }
 
@@ -528,7 +546,7 @@ kill_server_callback (server *serv)
    if (serv->connecting)
    {
       kill (serv->childpid, SIGKILL);
-      waitpid (serv->childpid, NULL, WNOHANG);
+      waitpid (serv->childpid, NULL, 0/*WNOHANG*/);
       if (serv->iotag != -1)
          fe_input_remove (serv->iotag);
       close (serv->childread);
@@ -908,9 +926,11 @@ xchat_misc_checks (void) /* this gets called every 2 seconds */
    "NAME KILL\nCMD /quote KILL %2 :&3\n\n"\
    "NAME LEAVE\nCMD /part &2\n\n"\
    "NAME M\nCMD /msg &2\n\n"\
+   "NAME ONOTICE\nCMD /notice @%c &2\n\n"\
    "NAME RAW\nCMD /quote &2\n\n"\
    "NAME SERVHELP\nCMD /quote HELP\n\n"\
    "NAME SV\nCMD /echo X-Chat %v\n\n"\
+   "NAME UMODE\nCMD /mode %n &2\n\n"\
    "NAME UPTIME\nCMD /quote STATS u\n\n"\
    "NAME VER\nCMD /ctcp %2 VERSION\n\n"\
    "NAME VERSION\nCMD /ctcp %2 VERSION\n\n"\
