@@ -18,6 +18,9 @@
 
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
 #include <stdio.h>
 #include <fcntl.h>
 #include <arpa/inet.h>
@@ -662,17 +665,12 @@ maingui_word_check (GtkXText *xtext, char *word)
    int i, dots;
    int len = strlen (word);
 
-   sess = gtk_object_get_user_data (GTK_OBJECT (xtext));
-
    if ((word[0] == '@' || word[0] == '+') && word[1] == '#')
       return WORD_CHANNEL;
 
    if (word[0] == '#' && word[1] != '#' && word[1] != 0)
       return WORD_CHANNEL;
 
-   if (find_name (sess, word))
-      return WORD_NICK;
-
    if (!strncasecmp (word, "irc://", 6))
       return WORD_URL;
 
@@ -694,12 +692,22 @@ maingui_word_check (GtkXText *xtext, char *word)
    if (!strncasecmp (word, "https:", 6))
       return WORD_URL;
 
+   sess = gtk_object_get_user_data (GTK_OBJECT (xtext));
+
+   if (find_name (sess, word))
+      return WORD_NICK;
+
    at = strchr (word, '@');  /* check for email addy */
    dot = strrchr (word, '.');
    if (at && dot)
    {
       if ((unsigned long) at < (unsigned long) dot)
-         return WORD_EMAIL;
+      {
+         if (strchr (word, '*'))
+            return WORD_HOST;
+         else
+            return WORD_EMAIL;
+      }
    }
 
    /* check if it's an IP number */
@@ -730,7 +738,7 @@ maingui_word_check (GtkXText *xtext, char *word)
    if (!strncasecmp (word + len - 4, ".edu", 4))
       return WORD_HOST;
 
-   if (strlen (word) > 5)
+   if (len > 5)
    {
       if (word[len-3] == '.' &&
           isalpha(word[len-2]) &&
@@ -1336,7 +1344,6 @@ gui_make_tab_window (struct session *sess)
                           GTK_SIGNAL_FUNC (focus_in), 0);
       gtk_signal_connect_object (GTK_OBJECT (main_window), "configure_event",
                           GTK_SIGNAL_FUNC (maingui_configure), 0);
-
       gtk_window_set_policy ((GtkWindow *) main_window, TRUE, TRUE, FALSE);
 
       main_box = gtk_vbox_new (0, 0);
@@ -1527,6 +1534,14 @@ relink_window (GtkWidget * w, struct session *sess)
       maingui_pagetofront (page);
       gtk_idle_add ((GtkFunction) maingui_refresh, (gpointer) sess);
 
+      /* dialog windows don't have this box */
+      if (sess->gui->userlistbox && !sess->is_dialog)
+      {
+         gtk_widget_realize (sess->gui->userlistbox);
+         gdk_window_set_background (sess->gui->userlistbox->window,
+                       &sess->gui->userlistbox->style->bg[GTK_STATE_NORMAL]);
+      }
+
       return 0;
    }
 }
